@@ -107,29 +107,37 @@ class MessageReader:
     def process_fetch_exception(self, e=None):
         # delay when partitionNotServing
         if Utils.is_partition_not_serving(e):
-            self.logger.warn("Partition: " + str(self.topicAndPartition.partitionId) +
-                             " is not serving state, sleep a while for waiting it work."
-                             + str(traceback.format_exc()))
+            if self.logger.isEnabledFor(logging.DEBUG):
+                self.logger.debug("Partition: " + str(self.topicAndPartition.partitionId) +
+                                  " is not serving state, sleep a while for waiting it work."
+                                  + str(traceback.format_exc()))
             time.sleep(self.consumerConfig.get_wait_partition_working_time())
 
+        if Utils.is_partition_not_exist(e):
+            if self.logger.isEnabledFor(logging.DEBUG):
+                self.logger.debug("Partition: " + str(self.topicAndPartition.partitionId) +
+                                  " not exist anymore, sleep a while for waiting it reduce."
+                                  + str(traceback.format_exc()))
+            time.sleep(self.consumerConfig.get_wait_partition_reduce_time())
+
         # if process message offset out of range, reset start offset
         if Utils.is_offset_out_of_range(e):
             if self.consumerConfig.is_reset_latest_offset_out_of_range():
-                self.logger.warn("Got PartitionOutOfRange error, " +
-                                 " offset by current latest offset"
-                                 + str(traceback.format_exc()))
+                self.logger.warning("Got PartitionOutOfRange error, " +
+                                    " offset by current latest offset" +
+                                    str(traceback.format_exc()))
                 self.startOffset.get_and_set(MessageOffset.LATEST_OFFSET)
                 self.lastCommitOffset = self.finishedOffset = - 1
                 self.lastCommitTime = Utils.current_time_mills()
             else:
-                self.logger.warn("Got PartitionOutOfRange error," +
-                                 " reset offset by current start offset"
-                                 + str(traceback.format_exc()))
+                self.logger.warning("Got PartitionOutOfRange error," +
+                                    " reset offset by current start offset" +
+                                    str(traceback.format_exc()))
                 self.startOffset.get_and_set(MessageOffset.START_OFFSET)
                 self.lastCommitOffset = self.finishedOffset = - 1
                 self.lastCommitTime = Utils.current_time_mills()
 
-        self.logger.warn("process unexcepted fetchException:" + str(traceback.format_exc()))
+        self.logger.warning("process unexcepted fetchException:" + str(traceback.format_exc()))
 
     #
     # query start offset to read, if failed, throw the exception
